<h1 align="center">types-jieba</h1>
<p align="center">
	<a href="https://pepy.tech/project/types-jieba"><img alt="Downloads" src="https://static.pepy.tech/badge/types-jieba"></a>
</p>

jieba 的类型库。

```bash
pip install types-jieba
```
